@@ -1,7 +1,7 @@
 """Function to sync a Preseem network metadata store to the new Preseem model."""
 import asyncio
 from collections import namedtuple
-import ipaddress
+from ipaddress import ip_address, ip_network
 import logging
 from uuid import UUID
 
@@ -105,8 +105,13 @@ async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, creat
                             for sf in bval.DESCRIPTOR.fields:
                                 smval = getattr(mval, sf.name)
                                 sbval = getattr(bval, sf.name)
+                                if sf.name == 'network_prefixes':
+                                    smval = set([ip_network(x) for x in smval])
+                                    sbval = set([ip_network(x) for x in sbval])
                                 if smval != sbval:
                                     achgs.append(f"{sf.name}[{smval}->{sbval}]")
+                        if not achgs:
+                            continue  # no further inspection, not actually a diff
                         changes.append(f'{f}: {",".join(achgs)}')
                     else:
                         changes.append(f'{f}: {mval} -> {bval}')
@@ -254,7 +259,7 @@ async def sync_preseem_model(preseem_model,
         unref_discs = set([x[0] for x in model_discs.items() if x[1].source == source])
         uuid_map = {}
         for item in items:
-            host = str(ipaddress.ip_address(item.host))  # validate ip address
+            host = str(ip_address(item.host))  # validate ip address
             key = (source, item.id)
             disc = disc_ids.get(key)
             if disc:
